# PySRRegressor Reference

::: pysr.PySRRegressor
    options:
        members:
            - fit
            - predict
            - from_file
            - sympy
            - latex
            - pytorch
            - jax
            - latex_table
            - refresh
        show_root_members_full_path: true
        heading_level: 2
